###################################################
### chunk number 1: preliminaries
###################################################
library("sets")
options(prompt = "R> ", continue = "+  ", width = 77)


###################################################
### chunk number 2: 
###################################################
s <- list(1, "1")
union(s, s)
intersect(s, s)


###################################################
### chunk number 3: sets1
###################################################
s <- set(1L, 2L, 3L)
print(s)


###################################################
### chunk number 4: 
###################################################
set("test", c, set("a", 2.5), list(1, 2))


###################################################
### chunk number 5: 
###################################################
set(1, pair(1,2), tuple(1L, 2L, 3L))


###################################################
### chunk number 6: 
###################################################
s2 <- as.set(2:4)
print(s2)


###################################################
### chunk number 7: setpredicates
###################################################
set_is_empty(set())
set(1) <= set(1,2)


###################################################
### chunk number 9: 
###################################################
length(s)


###################################################
### chunk number 10: 
###################################################
s | set("a")
s & s2
s %D% s2


###################################################
### chunk number 11: 
###################################################
s * s2
s ^ 2L


###################################################
### chunk number 12: 
###################################################
2 ^ s


###################################################
### chunk number 13: 
###################################################
set_complement(set(1), set(1,2,3))


###################################################
### chunk number 14: >
###################################################
!set(1)


###################################################
### chunk number 15: <
###################################################
## subsets
set_combn(s, 2L)


###################################################
### chunk number 16: 
###################################################
cl <- closure(set(set(1), set(2), set(3)), "union")
print(cl)
reduction(cl, "union")


###################################################
### chunk number 17: setsummary
###################################################
sum(s)
range(s)


###################################################
### chunk number 18: 
###################################################
s2 <- set(1,2, c, list(1,2))
print(s2)
s2[[c]] <- "foo"
s2[[list(1, 2)]] <- "bar"
print(s2)
s2[list("foo", 1)]


###################################################
### chunk number 19: iterators
###################################################
sapply(s, sqrt)
for (i in s) print(i)


###################################################
### chunk number 20: setouter
###################################################
set_outer(set(1,2), set(1,2,3), "/")


###################################################
### chunk number 21: 
###################################################
X <- c("A", "B", "C")
gset(support = X)


###################################################
### chunk number 22: 
###################################################
gset(support = X, universe = LETTERS[1:10])


###################################################
### chunk number 23: 
###################################################
multi <- 1:3
gset(support = X, memberships = multi)


###################################################
### chunk number 24: 
###################################################
ms <- c(0.1, 0.3, 1)
gset(support = X, memberships = ms)


###################################################
### chunk number 25: 
###################################################
gset(elements = list(e("A", 0.1), e("B", 0.2), e("C", 0.3)))


###################################################
### chunk number 26: 
###################################################
f <- function(x) switch(x, A = 0.1, B = 0.2, C = 1, 0)
gset(universe = X, charfun = f)


###################################################
### chunk number 27: 
###################################################
ms2 <- list(c(0.1, 0.3, 0.4), c(1, 1),
  gset(support = ms, memberships = multi))
gset(support = X, memberships = ms2)


###################################################
### chunk number 28: 
###################################################
X <- gset(c("A", "B", "C"), 4:6)
Y <- gset(c("B", "C", "D"), 1:3)

X | Y
X & Y


###################################################
### chunk number 29: 
###################################################
X + Y
X - Y
gset_product(X, Y)


###################################################
### chunk number 30: 
###################################################
!gset(1, 0.3)
X <- gset("a", universe = letters[1:3])
!X
!!X
!gset(1L, 2, universe = 1:3, bound = 3)


###################################################
### chunk number 31: 
###################################################
x <- gset(1:3, 1:3/3)
y <- gset(1:2, 1:2/2)
gset_mean(x, y)
gset_mean(x, y, "harmonic")

gset_mean(set(1), set(1, 2))


###################################################
### chunk number 32: 
###################################################
x <- gset(1:10, 1:10/10)
gset_transform_memberships(x, pmax, 0.5)


###################################################
### chunk number 33: 
###################################################
x <- gset(1, 2)
gset_transform_memberships(x, `*`, 0.5)


###################################################
### chunk number 34: 
###################################################
rep(x, 0.5)


###################################################
### chunk number 35: 
###################################################
gset_dilate(y)
gset_concentrate(y)
gset_normalize(y, 0.5)


###################################################
### chunk number 36: fuzzy
###################################################
x <- 1:10 / 10
y <- rev(x)
.S.(x, y)
fuzzy_logic("Fodor")
.S.(x, y)


###################################################
### chunk number 37: 
###################################################
X <- gset(c("A", "B", "C"), c(0.3, 0.5, 0.8))
print(X)
Y <- gset(c("B", "C", "D"), c(0.1, 0.3, 0.9))
print(Y)


###################################################
### chunk number 38: 
###################################################
fuzzy_logic("Zadeh")
X & Y
X | Y
gset_complement(X, Y)


###################################################
### chunk number 39: 
###################################################
fuzzy_logic("Fodor")
X & Y
X | Y
gset_complement(X, Y)


###################################################
### chunk number 40: fuzzyoff
###################################################
fuzzy_logic("Zadeh")


###################################################
### chunk number 41: 
###################################################
cut(X, 0.5)


###################################################
### chunk number 42: 
###################################################
N <- fuzzy_normal(mean = 0, sd = 1)
N(-3:3)

gset(charfun = N, universe = -3:3)


###################################################
### chunk number 43: 
###################################################
fuzzy_normal_gset(universe = -3:3)


###################################################
### chunk number 44: 
###################################################
fuzzy_poisson <- charfun_generator(dpois)
gset(charfun = fuzzy_poisson(10), universe = seq(0, 20, 2))


###################################################
### chunk number 45: 
###################################################
## creating a series of fuzzy normal sets
fuzzy_tuple(fuzzy_normal, 5)


###################################################
### chunk number 46: plot1
###################################################
## a fuzzy multiset
X <- gset(c("A", "B"), list(1:2/2, 0.5))
plot(X)


###################################################
### chunk number 47: plot2
###################################################
plot(fuzzy_bell)


###################################################
### chunk number 48: plot3
###################################################
## creating a sequence of sets
plot(fuzzy_tuple(fuzzy_cone, 10), col = gray.colors(10))


###################################################
### chunk number 49: plot4
###################################################
x <- fuzzy_normal_gset()
y <- fuzzy_trapezoid_gset(corners = c(5, 10, 15, 17), height = c(0.7, 1))
plot(tuple(x, y), lty = 3)
lines(x | y, col = 2)
lines(gset_mean(x, y), col = 3, lty = 2)


###################################################
### chunk number 50: plot1fig
###################################################
## a fuzzy multiset
X <- gset(c("A", "B"), list(1:2/2, 0.5))
plot(X)


###################################################
### chunk number 51: plot2fig
###################################################
plot(fuzzy_bell)


###################################################
### chunk number 52: plot3fig
###################################################
## creating a sequence of sets
plot(fuzzy_tuple(fuzzy_cone, 10), col = gray.colors(10))


###################################################
### chunk number 53: plot4fig
###################################################
x <- fuzzy_normal_gset()
y <- fuzzy_trapezoid_gset(corners = c(5, 10, 15, 17), height = c(0.7, 1))
plot(tuple(x, y), lty = 3)
lines(x | y, col = 2)
lines(gset_mean(x, y), col = 3, lty = 2)


###################################################
### chunk number 54: 
###################################################
x <- set("1", 1L, 1, 3.3 - 2.2, 1.1)
print(x)

y <- set(1, 1.1, 2L, "2")
print(y)
1L %e% y

x | y


###################################################
### chunk number 55: 
###################################################
X <- cset(x, matchfun = match)
print(X)
Y <- cset(y, matchfun = match)
print(Y)
1L %e% Y
X | Y


###################################################
### chunk number 56: 
###################################################
FUN <- matchfun(function(x, y) isTRUE(all.equal(x, y)))
X <- cset(x, matchfun = FUN)
print(X)
Y <- cset(y, matchfun = FUN)
print(Y)
1L %e% Y

X | Y


###################################################
### chunk number 57: 
###################################################
sets_options("matchfun", match)
cset(x)
cset(y)

cset(1:3) <= cset(c("1", "2", "3"))


###################################################
### chunk number 58: 
###################################################
### restore package defaults
sets_options("matchfun", NULL)


###################################################
### chunk number 59: 
###################################################
cset(letters[1:5], orderfun = 5:1)

FUN <- function(x) order(as.character(x), decreasing = TRUE)
Z <- cset(letters[1:5], orderfun = FUN)
print(Z)
as.character(Z)


###################################################
### chunk number 60: 
###################################################
o <- ordered(c("a", "b", "a"), levels = c("b", "a"))
as.set(o)
as.gset(o)
as.cset(o)


###################################################
### chunk number 61: 
###################################################
as.cset(c("A", "quick", "brown", "fox"))
as.cset(c("A", "quick", "brown", "fox", "quick"))


###################################################
### chunk number 62: 
###################################################
set.seed(4711)
l <- r2dtable(1000, r = 1:2, c = 2:1)


###################################################
### chunk number 63: 
###################################################
l[1:2]


###################################################
### chunk number 64: 
###################################################
s <- as.gset(l)
print(s)


###################################################
### chunk number 65: 
###################################################
for (i in s) s[[i]] <- i[1]
print(s)


###################################################
### chunk number 66: 
###################################################
gset_memberships(s) / 1000


###################################################
### chunk number 67: 
###################################################
fisher.test(l[[1]])$p.value


###################################################
### chunk number 68: 
###################################################
data("fuzzy_docs")
print(fuzzy_docs[8:9])


###################################################
### chunk number 69: 
###################################################
library("proxy")
d <- dist(fuzzy_docs, gset_dissimilarity)


###################################################
### chunk number 70: 
###################################################
cl1 <- hclust(d, "ward")


###################################################
### chunk number 71: 
###################################################
labs1 <- cutree(cl1, 2)
print(labs1)


###################################################
### chunk number 72: clusterplot
###################################################
plot(cl1)


###################################################
### chunk number 73: 
###################################################
tdm <- set_outer(c("neural networks", "fuzzy", "image"),
  fuzzy_docs, `%in%`)
print(tdm)


###################################################
### chunk number 74: 
###################################################
d <- dist(tdm, "Jaccard", by_rows = FALSE)


###################################################
### chunk number 75: 
###################################################
cl2 <- hclust(d, "ward")


###################################################
### chunk number 76: 
###################################################
labs2 <- cutree(cl2, 2)
print(labs2)
table(labs1, labs2)


###################################################
### chunk number 77: clusterplot2
###################################################
plot(cl2)


